% Example demonstrating the use of gridnm() on the Rosenbrock function
% (C)2006-2011 Arpad Buermen
% Distributed under the terms of LGPL v2.1. 

% Function 
func='rb';

% Initial point
x0=[-1.2;1];

% Dimensionality
[ndim,dummy]=size(x0);

% Initial simplex side vector lengths 
%   simplex origin is at initial point
%   sides are aligned with cartesian basis
d=abs(x0*0.05+(x0==0)*0.00025);

% Initial simplex
%   origin+side vectors
s0=[x0,x0*ones(1,ndim)+diag(d)];

% Initial grid origin
dorigin0=x0;

% Initial grid scaling
d0=ones(ndim,1)*min(abs(d))/10;

% Tolerances
fabstol=1e-15;
xabstol=1e-8;
reltol=1e-15;

% Maximam number of CF evaluations
nlim=100000; 

% Run algorithm
[x,f,n]=gridnm(func, s0, dorigin0, d0, nlim, fabstol, xabstol, reltol);

disp('Final result');
x
f
n

